@@ -9,6 +9,7 @@
 #include <KPublicTransport/Journey>
 
 #include <QAbstractItemModel>
+#include <QTimer>
 
 #include <vector>
 
@@ -36,6 +37,8 @@ class JourneySectionModel : public QAbstractListModel
 
     // when disabled, progress is always 0 / not passed
     Q_PROPERTY(bool showProgress MEMBER m_showProgress NOTIFY showProgressChanged)
+    Q_PROPERTY(int sectionCount READ sectionCount NOTIFY journeySectionChanged)
+
 public:
     explicit JourneySectionModel(QObject *parent = nullptr);
     ~JourneySectionModel();
@@ -66,6 +69,8 @@ public:
     void setCurrentDateTime(const QDateTime &dt);
     QDateTime currentDateTime() const;
 
+    int sectionCount() const;
+
 Q_SIGNALS:
     void journeySectionChanged();
     void departureTrailingSegmentLengthChanged();
@@ -86,6 +91,7 @@ private:
     std::vector<Data> m_data;
     float m_departureTrailingLength = 0.0f;
     float m_arrivalLeadingLength = 0.0f;
+    QTimer m_updateTimer;
 
     bool m_showProgress = false;
 
