@@ -324,10 +324,16 @@ void LiveDataManager::updateJourneyData(const KPublicTransport::JourneySection &
     ld.store(resId, LiveData::AllTypes);
 
     // update reservation with live data
-    const auto newRes = PublicTransport::mergeJourney(res, ld.journey);
-    if (!ReservationHelper::equals(res, newRes) && res.typeId() == newRes.typeId()) {
-        m_resMgr->updateReservation(resId, newRes);
+    std::vector<ReservationManager::ReservationChange> resUpdates;
+    for (const auto &id : m_resMgr->reservationsForBatch(resId)) {
+        const auto r = m_resMgr->reservation(id);
+        const auto newRes = PublicTransport::mergeJourney(r, ld.journey);
+        if (!ReservationHelper::equals(r, newRes) && r.typeId() == newRes.typeId()) {
+            resUpdates.emplace_back(id, newRes);
+        }
     }
+    qCDebug(Log) << "submitting" << resUpdates.size() << "reservation changes";
+    m_resMgr->updateBatch(resUpdates);
 
     // emit update signals
     Q_EMIT journeyUpdated(resId);
@@ -619,7 +625,7 @@ struct {
     {4 * 3600, 15 * 60}, // for <4h we poll every 15 minutes
     {24 * 3600, 3600}, // for <1d we poll once per hour
     {4 * 24 * 3600, 24 * 3600}, // for <4d we poll once per day
-    {60 * 24 * 3600, MAX_POLL_INTERVAL}, // anything before we should at least do one poll to get full details right away
+    {std::numeric_limits<int>::max(), MAX_POLL_INTERVAL}, // anything before we should at least do one poll to get full details right away
 };
 
 int LiveDataManager::nextPollTimeForReservation(const QString &resId) const
