@@ -14,6 +14,8 @@
 
 #include <KContacts/Address>
 
+#include <KUnitConversion/Converter>
+
 #include <KCountry>
 #include <KFormat>
 #include <KLocalizedString>
@@ -35,6 +37,7 @@ using namespace KAndroidExtras;
 #include <cstring>
 
 using namespace KItinerary;
+using namespace Qt::StringLiterals;
 
 static KContacts::Address variantToKContactsAddress(const QVariant &obj)
 {
@@ -73,6 +76,34 @@ static bool addressEmptyExceptForCountry(const KContacts::Address &address)
         && !address.country().isEmpty();
 }
 
+static bool includeCountry(const KContacts::Address &address, const QVariant &otherObj, const QString &homeCountryIsoCode)
+{
+    if (homeCountryIsoCode.isEmpty()) {
+        return true;
+    }
+
+    if (address.country() != homeCountryIsoCode) {
+        return true;
+    }
+
+    const KContacts::Address otherAddress = variantToKContactsAddress(otherObj);
+    return !otherAddress.country().isEmpty() && address.country() != otherAddress.country();
+};
+
+QString Localizer::formatCountryWithContext(const QVariant &obj, const QVariant &otherObj, const QString &homeCountryIsoCode)
+{
+    const KContacts::Address address = variantToKContactsAddress(obj);
+
+    if (address.isEmpty()) {
+        return {};
+    }
+
+    if (includeCountry(address, otherObj, homeCountryIsoCode)) {
+        return KCountry::fromAlpha2(address.country()).name();
+    }
+    return {};
+}
+
 QString Localizer::formatAddressWithContext(const QVariant &obj, const QVariant &otherObj, const QString &homeCountryIsoCode)
 {
     const KContacts::Address address = variantToKContactsAddress(obj);
@@ -81,32 +112,10 @@ QString Localizer::formatAddressWithContext(const QVariant &obj, const QVariant
         return {};
     }
 
-    const bool includeCountry = [&] {
-        if (homeCountryIsoCode.isEmpty()) {
-            return true;
-        }
-
-        if (!addressEmptyExceptForCountry(address)) {
-            return true;
-        }
-
-        if (address.country() != homeCountryIsoCode) {
-            return true;
-        }
-
-        const KContacts::Address otherAddress = variantToKContactsAddress(otherObj);
-        if (!otherAddress.country().isEmpty() && address.country() != otherAddress.country()) {
-            return true;
-        }
-
-        return false;
-    }();
-
-    if (includeCountry) {
+    if (!addressEmptyExceptForCountry(address) || includeCountry(address, otherObj, homeCountryIsoCode)) {
         return address.formatted(KContacts::AddressFormatStyle::MultiLineInternational);
-    } else {
-        return address.formatted(KContacts::AddressFormatStyle::MultiLineDomestic);
     }
+    return address.formatted(KContacts::AddressFormatStyle::MultiLineDomestic);
 }
 
 static bool needsTimeZone(const QDateTime &dt)
@@ -206,29 +215,28 @@ QString Localizer::formatDateOrDateTimeLocal(const QVariant &obj, const QString
     return QLocale().toString(dt.toLocalTime(), QLocale::ShortFormat);
 }
 
-QString Localizer::formatDuration(int seconds) const
+QString Localizer::formatTimeZoneOffset(qint64 seconds)
 {
     if (seconds < 0) {
         return QLocale().negativeSign() + KFormat().formatDuration((-seconds * 1000), KFormat::HideSeconds);
     }
-    return KFormat().formatDuration(seconds * 1000, KFormat::HideSeconds);
+    return QLocale().positiveSign() + KFormat().formatDuration((seconds * 1000), KFormat::HideSeconds);
 }
 
-QString Localizer::formatDistance(int meter)
+QString Localizer::formatDuration(int seconds)
 {
-    if (meter < 1000) {
-        return i18nc("distance in meter", "%1 m", meter);
-    }
-    if (meter < 10000) {
-        return i18nc("distance in kilometer", "%1 km", ((int)meter / 100) / 10.0);
-    }
-    return i18nc("distance in kilometer", "%1 km", (int)qRound(meter / 1000.0));
+    const auto opts = static_cast<KFormat::DurationFormatOptions>(KFormat::AbbreviatedDuration | KFormat::HideSeconds); // ### workaround for KF < 6.12
+    return KFormat().formatDuration((quint64)seconds * 1000, opts);
 }
 
-QString Localizer::formatSpeed(int km_per_hour)
+QString Localizer::formatSpeed(double km_per_hour, KFormat::DistanceFormatOptions formatOpts)
 {
-    // TODO locale-specific unit conversion
-    return i18nc("speed in kilometers per hour", "%1 km/h", km_per_hour);
+    auto targetUnit = KUnitConversion::UnitId::KilometerPerHour;
+    if (const auto ms = QLocale().measurementSystem(); (ms == QLocale::ImperialUKSystem || ms == QLocale::ImperialUSSystem) && (formatOpts & KFormat::MetricDistanceUnits) == 0) {
+        targetUnit = KUnitConversion::UnitId::MilePerHour;
+    }
+
+    return KUnitConversion::Converter().convert(KUnitConversion::Value(km_per_hour, KUnitConversion::UnitId::KilometerPerHour), targetUnit).round(0).toSymbolString();
 }
 
 QString Localizer::formatWeight(int gram)
@@ -242,9 +250,19 @@ QString Localizer::formatWeight(int gram)
     return i18nc("weight in kilogram", "%1 kg", (int)qRound(gram / 1000.0));
 }
 
-QString Localizer::formatTemperature(double temperature)
+QString Localizer::formatTemperatureRange(double minTemperature, double maxTemperature, bool useFahrenheit)
 {
-    return i18nc("temperature", "%1°C", (int)qRound(temperature));
+    using KUnitConversion::UnitId;
+
+    const auto targetUnit = useFahrenheit ? UnitId::Fahrenheit : UnitId::Celsius;
+
+    const auto minVal = KUnitConversion::Converter().convert(KUnitConversion::Value(minTemperature, UnitId::Celsius), targetUnit).round(0);
+    const auto maxVal = KUnitConversion::Converter().convert(KUnitConversion::Value(maxTemperature, UnitId::Celsius), targetUnit).round(0);
+
+    if (minVal.number() == maxVal.number()) {
+        return minVal.toSymbolString();
+    }
+    return i18nc("temperature range", "%1 / %2", minVal.toSymbolString(), maxVal.toSymbolString());
 }
 
 QString Localizer::formatCurrency(double value, const QString &isoCode)
