@@ -237,10 +237,17 @@ QString ReservationManager::addReservationWithPostProcessing(const QVariant &res
     return !l.isEmpty() ? l.at(0) : QString();
 }
 
-void ReservationManager::updateReservation(const QString &resId, const QVariant &res)
+void ReservationManager::updateReservation(const QString &resId, QVariant res)
 {
     const auto oldRes = reservation(resId);
 
+    ExtractorPostprocessor postproc;
+    postproc.process({res});
+    const auto postProcResult = postproc.result();
+    if (postProcResult.size() == 1) {
+        res = postProcResult.at(0);
+    }
+
     storeReservation(resId, res);
     Q_EMIT reservationChanged(resId);
 
@@ -261,6 +268,28 @@ void ReservationManager::storeReservation(const QString &resId, const QVariant &
     m_reservations.insert(resId, res);
 }
 
+void ReservationManager::updateBatch(const std::vector<ReservationManager::ReservationChange> &batch)
+{
+    if (batch.empty()) {
+        return;
+    }
+
+    QString batchId;
+    for (const auto &change : batch) {
+        const auto bid = batchForReservation(change.id);
+        if (batchId.isEmpty()) {
+            batchId = bid;
+        }
+        assert(batchId == bid && !batchId.isEmpty());
+        storeReservation(change.id, change.res);
+    }
+    // TODO can probably be done more efficiently by only moving batchId
+    std::sort(m_batches.begin(), m_batches.end(), [this](const auto &lhs, const auto &rhs) {
+        return SortUtil::isBefore(reservation(lhs), reservation(rhs));
+    });
+    Q_EMIT batchContentChanged(batchId);
+}
+
 void ReservationManager::removeReservation(const QString &id)
 {
     const auto batchId = m_resToBatchMap.value(id);
